@@ -45,7 +45,8 @@ class ThesaurusTermsSearchView(MethodPublisher):
             allow_archives = False
         return [{'value': term.caption,
                  'caption': term.caption}
-                for term in unique(thesaurus.findTerms(query, extract_name, autoexpand, glob, limit, exact=True),
+                for term in unique(thesaurus.findTerms(query, extract_name, autoexpand, glob, limit,
+                                                       exact=True, stemmed=True),
                                    idfun=lambda x: x.caption)
                          if allow_archives or (term.status != STATUS_ARCHIVED)]
 
@@ -61,6 +62,7 @@ class ThesaurusTermsSearchView(MethodPublisher):
             allow_archives = False
         return [{'value': term.label,
                  'caption': term.label}
-                for term in unique(thesaurus.findTerms(query, extract_name, autoexpand, glob, limit, exact=True),
+                for term in unique(thesaurus.findTerms(query, extract_name, autoexpand, glob, limit,
+                                                       exact=True, stemmed=True),
                                    idfun=lambda x: x.label)
                          if allow_archives or (term.status != STATUS_ARCHIVED)]
