@@ -133,13 +133,19 @@ class ThesaurusTermsTreeView(BaseBackView, TemplateBasedPage, ajax.AJAXRequestHa
         if term.usage is not None:
             term = term.usage
         result = []
-        parents = list(reversed(term.getParents()))
-        self._getNodes(parents[0], result, [ t.label for t in parents ])
         writer = getUtility(IJSONWriter)
-        return writer.write({ 'status': 'OK',
-                              'parent': parents[0].label,
-                              'term': term.label,
-                              'nodes': result })
+        parents = list(reversed(term.getParents()))
+        if parents:
+            self._getNodes(parents[0], result, [ t.label for t in parents ])
+            return writer.write({ 'status': 'OK',
+                                  'parent': parents[0].label,
+                                  'term': term.label,
+                                  'nodes': result })
+        else:
+            return writer.write({ 'status': 'OK',
+                                  'parent': term.label,
+                                  'term': term.label,
+                                  'nodes': result })
 
     @ajax.handler
     def switchExtract(self):
